"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const fs_1 = require("fs");
const inquirer = require("inquirer");
const path = require("path");
class Create extends command_1.default {
    async run() {
        // tslint:disable-next-line:no-this-assignment
        const self = this;
        const { args } = this.parse(Create);
        const to = path.resolve(args.name);
        if (fs_1.existsSync(to))
            this.log(`${args.name} already exists`);
        // just prompt for input
        const firstResponses = await inquirer.prompt([
            {
                name: 'name',
                message: 'Project name',
                default: args.name
            },
            {
                name: 'description',
                message: 'Description of your project'
            },
            {
                name: 'author',
                message: 'Name of author'
            },
            {
                name: 'repository',
                message: 'Project repository url'
            },
            {
                name: 'size',
                message: 'Project size to help allocate some features',
                type: 'list',
                choices: [{ name: 'small' }, { name: 'medium' }, { name: 'enterprise' }],
            },
            {
                name: 'features',
                message: 'select features/modules to speed up your project',
                type: 'checkbox',
                choices: [{ name: 'authentication' }, { name: 'chat' }, { name: 'social' }, { name: 'push-notification' }],
            },
            {
                name: 'databaseType',
                message: 'select a database type',
                type: 'list',
                choices: [{ name: 'NoSQL' }, { name: 'SQL' }, { name: 'Graph' }],
            },
            {
                name: 'confirm',
                message: 'You are sure of the options selected?',
                type: 'confirm',
            },
        ]);
    }
}
Create.description = 'Create new linaframework project';
Create.examples = [
    '$ lina create my-app',
];
Create.args = [
    {
        name: 'name',
        required: true,
        description: 'Please provide a name for your app',
    }
];
Create.flags = {
    help: command_1.flags.help({ char: 'h' }),
    // flag with a value (-n, --name=VALUE)
    name: command_1.flags.string({ char: 'n', description: 'name to print' }),
    // flag with no value (-f, --force)
    force: command_1.flags.boolean({ char: 'f' }),
};
exports.default = Create;
